==> shrinkwrap-resolver-api-2.1.1-sources.jar: org/jboss/shrinkwrap/resolver/api/VersionRangeResult.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.shrinkwrap.resolver.api;

import java.util.List;

/**
 * Representation of artifacts available versions.
 *
 * {@see org.sonatype.aether.resolution.VersionRangeResult}
 * @author <a href="mailto:mmatloka@gmail.com">Michal Matloka</a>
 */
public interface VersionRangeResult<COORDINATE extends Coordinate> {

    /**
     * @return coordinate of lowest available version matching requested range. Contained in {@see #getVersions} on first position. Null if no versions were found.
     */
    COORDINATE getLowestVersion();

    /**
     * @return coordinate of highest available version matching requested range. Contained in {@see #getVersions} on last position. Null if no versions were found.
     */
    COORDINATE getHighestVersion();

    /**
     * @return ordered list (from lowest to highest) of available versions.
     */
    List<COORDINATE> getVersions();
}

==> shrinkwrap-resolver-api-3.3.1-sources.jar: org/jboss/shrinkwrap/resolver/api/VersionRangeResult.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.shrinkwrap.resolver.api;

import java.util.List;

/**
 * Representation of artifacts available versions.
 *
 * @see <tt>org.sonatype.aether.resolution.VersionRangeResult</tt>
 * @author <a href="mailto:mmatloka@gmail.com">Michal Matloka</a>
 */
public interface VersionRangeResult<COORDINATE extends Coordinate> {

    /**
     * @return coordinate of lowest available version matching requested range. Contained in {@link #getVersions} on first position. Null if no versions were found.
     */
    COORDINATE getLowestVersion();

    /**
     * @return coordinate of highest available version matching requested range. Contained in {@link #getVersions} on last position. Null if no versions were found.
     */
    COORDINATE getHighestVersion();

    /**
     * @return ordered list (from lowest to highest) of available versions.
     */
    List<COORDINATE> getVersions();
}
